@@ -26,7 +26,7 @@ if [ "$OLD_DIR" ]; then
 	mv $OLD_DIR $CORRECT_DIR
 fi
 
-dbus-send --system --print-reply --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:connectable > /dev/null
+BK_MODE=`egrep ^mode $CORRECT_DIR/config|awk '{ print $2 }'`
 
 NAME=""
 
@@ -42,13 +42,7 @@ if [ "$NAME" ]; then
 	dbus-send --print-reply --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetName string:"$NAME" > /dev/null
 fi
 
-MODE=""
-
-if [ -f "$CORRECT_DIR/config" ]; then
-	MODE=`egrep ^mode $CORRECT_DIR/config|awk '{ print $2 }'`
-fi
-
-if [ "$MODE" ]; then
-	dbus-send --print-reply --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:$MODE > /dev/null
+if [ "$BK_MODE" ]; then
+	dbus-send --print-reply --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:$BK_MODE > /dev/null
 fi
 
